#!/usr/bin/env python
# -*- coding: utf-8 -*-
# vim: ai ts=4 sts=4 et sw=4 nu

from __future__ import (unicode_literals, absolute_import,
                        division, print_function)

l10n_strings = {
    "default_locale": "en",
    "locales": {
        "en": {
            "isocode": {
                "textContent": "en"
            },
            "autonym": {
                "textContent": "English"
            },
            "homepage": {
                "alt": "Homepage",
                "title": "Homepage"
            },
            "choose-language": {
                "placeholder": "Choose a language..."
            },
            "ui-language-switcher": {
                "title": "Interface language"
            },
            "search": {
                "textContent": "Search"
            },
            "author": {
                "textContent": "Author",
                "placeholder": "List books of a single Author"
            },
            "cover-img": {
                "alt": "Book Cover",
                "title": "Book Cover"
            },
            "cover": {
                "textContent": "(cover)"
            },
            "filter": {
                "textContent": "Filter:"
            },
            "popularity": {
                "textContent": "Popularity"
            },
            "sort": {
                "textContent": "Sort:"
            },
            "sort-popularity": {
                "textContent": "Sort books by popularity"
            },
            "sort-title": {
                "textContent": "Sort books by title"
            },
            "title": {
                "textContent": "Title"
            },
            "format": {
                "textContent": "Format"
            },
            "loading": {
                "textContent": "Loading..."
            },
            "no-data": {
                "textContent": "No data available in table"
            },
            "prev": {
                "textContent": "Previous"
            },
            "next": {
                "textContent": "Next"
            },
            "language": {
                "textContent": "Language"
            },
            "any-languages": {
                "textContent": "Choose the Catalog"
            },
            "main-languages": {
                "textContent": "Main languages"
            },
            "other-languages": {
                "textContent": "Other languages"
            },
            "author-anonymous": {
                "textContent": "Anonymous"
            },
            "author-various": {
                "textContent": "Various"
            },
            "license": {
                "textContent": "License"
            },
            "license-pd": {
                "textContent": "Public domain in the USA."
            },
            "nb-downloads": {
                "textContent": "{[ plural(nb) ]}"
            },
            "nb-downloads[one]": {
                "textContent": "1 download in the last 30 days."
            },
            "nb-downloads[other]": {
                "textContent": "{{nb}} downloads in the last 30 days."
            },
            "top-title": {
                "textContent": "Project Gutenberg Library"
            },
            "sub-title": {
                "textContent": "The first producer of free ebooks"
            },
            "table-previous": {
                "textContent": "Previous"
            },
            "table-next": {
                "textContent": "Next"
            },
            "about-1": {
                "textContent": "Project Gutenberg offers over "
                               "45,000 free ebooks"
            },
            "about-2": {
                "textContent": "Choose among free epub books, "
                               "free kindle books."
            },
            "about-3": {
                "textContent": "Download them or read them online."
            },
            "about-4": {
                "textContent": "We carry high quality ebooks"
            },
            "about-5": {
                "textContent": "All our ebooks were previously "
                               "published by bona fide publishers."
            },
            "about-6": {
                "textContent": "We digitized and diligently "
                               "proofread them with the help of "
                               "thousands of volunteers."
            }
        },
        "fr": {
            "isocode": {
                "textContent": "fr"
            },
            "autonym": {
                "textContent": "Français"
            },
            "homepage": {
                "alt": "Page d’accueil",
                "title": "Page d’accueil"
            },
            "choose-language": {
                "placeholder": "Choisissez une langue..."
            },
            "ui-language-switcher": {
                "title": "Langue de l’interface"
            },
            "search": {
                "textContent": "Rechercher"
            },
            "author": {
                "textContent": "Auteur",
                "placeholder": "Voir les livres d'un seul auteur"
            },
            "cover-img": {
                "title": "Couverture du livre",
                "alt": "Couverture du livre"
            },
            "cover": {
                "textContent": "(couverture)"
            },
            "filter": {
                "textContent": "Filtrer :"
            },
            "popularity": {
                "textContent": "Popularité"
            },
            "sort": {
                "textContent": "Trier :"
            },
            "sort-popularity": {
                "textContent": "Trier les livres par popularité"
            },
            "sort-title": {
                "textContent": "Trier les livres par titre"
            },
            "title": {
                "textContent": "Titre"
            },
            "format": {
                "textContent": "Format"
            },
            "loading": {
                "textContent": "Chargement..."
            },
            "no-data": {
                "textContent": "Pas de données disponibles"
            },
            "prev": {
                "textContent": "Précédent"
            },
            "next": {
                "textContent": "Suivant"
            },
            "language": {
                "textContent": "Langue"
            },
            "any-languages": {
                "textContent": "Choisir le catalogue"
            },
            "main-languages": {
                "textContent": "Langues principales"
            },
            "other-languages": {
                "textContent": "Autres langues"
            },
            "author-anonymous": {
                "textContent": "Anonyme"
            },
            "author-various": {
                "textContent": "Plusieurs"
            },
            "license": {
                "textContent": "Licence"
            },
            "license-pd": {
                "textContent": "Domaine public aux États-Unis."
            },
            "nb-downloads": {
                "textContent": "{[ plural(nb) ]}"
            },
            "nb-downloads[one]": {
                "textContent": "1 téléchargement au cours des "
                               "30 derniers jours."
            },
            "nb-downloads[other]": {
                "textContent": "{{nb}} téléchargements au cours des "
                               "30 derniers jours."
            },
            "top-title": {
                "textContent": "Bibliothèque du projet Gutenberg"
            },
            "sub-title": {
                "textContent": "Premier producteur d’ebooks gratuits"
            },
            "table-previous": {
                "textContent": "Prédédent"
            },
            "table-next": {
                "textContent": "Suivant"
            },
            "about-1": {
                "textContent": "Le Projet Gutenberg offre plus de "
                               "45 000 ebooks gratuits"
            },
            "about-2": {
                "textContent": "Choisissez parmi les livres epub ou "
                               "kindle gratuits."
            },
            "about-3": {
                "textContent": "Téléchargez-les ou lisez-les en ligne."
            },
            "about-4": {
                "textContent": "Nous attachons beaucoup d’importance "
                               "à la qualité des ebooks"
            },
            "about-5": {
                "textContent": "Tous nos livres électroniques "
                               "ont été auparavant publiés par des "
                               "éditeurs classiques."
            },
            "about-6": {
                "textContent": "Nous les numérisons et les relisons "
                               "soigneusement avec l’aide de milliers "
                               "de volontaires."}
            }
    }
}
